import React from 'react';
import { IconBaseProps } from '@digigov/react-icons/IconBase';
export interface SvgIconProps extends IconBaseProps<'svg'> {
    /**
     * size is optional.
     * size prop declares the size of the svg icon.
     * @value 'xs'
     * @value 'sm'
     * @value 'md'
     * @value 'lg'
     * @value 'xl'
     * @default 'sm'
     */
    size?: 'xs' | 'sm' | 'md' | 'lg' | 'xl';
    /**
     * color property styles svg icon with Gov.gr palette's basic colors.
     * color property is optional.
     * @value 'base-content'
     * @value 'dark', always dark, among all themes
     * @value 'white', always white, among all themes
     * @value 'gray'
     * @value 'primary'
     * @value 'success'
     * @value 'warning'
     * @value 'error'
     * @value 'focus', use only in focus state, in dark background
     * @value 'info'
     * @value 'link'
     */
    color?: 'base-content' | 'dark' | 'white' | 'gray' | 'primary' | 'success' | 'warning' | 'error' | 'focus' | 'info' | 'link';
}
/**
 * Use SvgIcon as global svg component.
 *  SvgIcon can be used inside other svg components as children such as CheckIcon, CaretIcon etc.
 */
export declare const SvgIcon: React.ForwardRefExoticComponent<Omit<SvgIconProps, "ref"> & React.RefAttributes<SVGSVGElement>>;
export default SvgIcon;
