import React from 'react';
import clsx from 'clsx';
import * as icons from '@digigov/react-icons/icons';
import type { IconTypes } from '@digigov/react-icons/icons';
import SvgIcon, { SvgIconProps } from '@digigov/react-icons/SvgIcon';

export type IconProps<N extends keyof IconTypes> = SvgIconProps &
  IconTypes[N] & {
    /**
     * ref is optional.
     * ref prop declares the reference of the svg icon component.
     * It can be used to to access the DOM element and the React element.
     */
    ref?: React.Ref<SVGSVGElement>;
    /**
     * icon is optional, but strongly recommended.
     * Default value is 'chevron'.
     * Use this prop to display the icon you want.
     */
    icon?: N;
  };

type IconComponent = <C extends keyof IconTypes>(
  props: IconProps<C>
) => React.ReactNode | null;
export type IconNames = keyof IconTypes;
/**
 * Icon is used whenever we need a GOV.GR icon.
 * Choose the icon from the list in icon prop.
 */
export const Icon: IconComponent = React.forwardRef<
  SVGSVGElement,
  IconProps<IconNames>
>(function Icon(
  { icon = 'chevron', className, ...props }: IconProps<IconNames>,
  ref
) {
  const IconComponent = icons[icon];
  // eslint-disable-next-line @typescript-eslint/ban-ts-comment
  // @ts-ignore
  const iconProps = IconComponent?.props.reduce((compProps, propName) => {
    const value = props[propName];
    delete props[propName];
    return {
      ...compProps,
      [propName]: value,
    };
  }, {});

  return (
    <SvgIcon
      ref={ref}
      {...props}
      className={clsx(className, {
        [`ds-svg-icon--${icon}`]: true,
      })}
    >
      <IconComponent {...iconProps} />
    </SvgIcon>
  );
});

export default Icon;
